@@ -72,7 +72,7 @@ def test_query_gen():
     i = 0
     for answer in docs.query_gen("What is Frederick Bates's greatest accomplishment?"):
         i += 1
-    assert i > 2
+    assert i >= 2
     os.remove(doc_path)
 
 
@@ -117,9 +117,7 @@ def test_bad_context():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(
-        llm=OpenAI(temperature=0.1, model_name="text-davinci-003", max_tokens=100)
-    )
+    docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     answer = docs.query(
         "What year was Barack Obama born?",
@@ -208,4 +206,7 @@ def test_citation():
         f.write(r.text)
     docs = paperqa.Docs()
     docs.add(doc_path)
-    assert list(docs.docs.values())[0]["metadata"][0]["key"] == "Wikipedia2023"
+    assert (
+        list(docs.docs.values())[0]["metadata"][0]["key"] == "Wikipedia2023"
+        or list(docs.docs.values())[0]["metadata"][0]["key"] == "Frederick2023"
+    )
